![build status](https://api.travis-ci.com/lucenaproject/lib-python.svg?branch=master)
[![GitHub](https://img.shields.io/github/license/mashape/apistatus.svg)](https://opensource.org/licenses/MIT)


>
> At this early stage, the most important thing is to generate inertia.
> —AF
>

# Lucena Python library


The Python core library for building microservices in Lucena Project.
